@@ -208,6 +208,30 @@ static CandidateController *sharedController;
   [indexSet release];
 }
 
+/**
+ * deselect a candidate
+ */
+- (void)deselectCandidate
+{
+  [table deselectAll:nil];
+}
+
+/**
+ * Set a page label
+ */
+- (void)setPage:(int)index:(int)max
+{
+  NSString *label;
+
+  if (index > 0)
+    label = [NSString stringWithFormat:@"%d / %d",
+                      index, max];
+  else
+    label = [NSString stringWithFormat:@"- / %d", max];
+
+  [textfield setStringValue:label];
+}
+
 /**
  * Button press action
  */
@@ -338,3 +362,35 @@ selectCandidate(int inIndex)
 
   return noErr;
 }
+
+/**
+ * deselect a candidate
+ * This function called by a Carbon function.
+ */
+OSStatus
+deselectCandidate(int inIndex)
+{
+  NSAutoreleasePool *localPool;
+
+  localPool = [[NSAutoreleasePool alloc] init];        
+  [[CandidateController sharedController] deselectCandidate];
+  [localPool release];
+
+  return noErr;
+}
+
+/**
+ * Set a page label
+ * This function called by a Carbon function.
+ */
+OSStatus
+setPage(int inIndex, int inMax)
+{
+  NSAutoreleasePool *localPool;
+
+  localPool = [[NSAutoreleasePool alloc] init];        
+  [[CandidateController sharedController] setPage:inIndex:inMax];
+  [localPool release];
+
+  return noErr;
+}
