@@ -45,6 +45,8 @@ pascal ComponentResult MUIMComponentDispatch(ComponentParameters * inParams,
 long gInstanceRefCount = 0;
 MenuRef gTextServiceMenu = nil;
 
+//SInt32 gProp = kTextServiceInputModePropertyTag;
+
 static ComponentResult CallMUIMFunction(ComponentParameters * inParams,
                                         ProcPtr inProcPtr, SInt32 inProcInfo);
 static ComponentResult CallMUIMFunctionWithStorage(Handle inStorage,
@@ -68,92 +70,103 @@ MUIMComponentDispatch(ComponentParameters * inParams, Handle inSessionHandle)
 {
   ComponentResult result = noErr;
 
+  //DEBUG_PRINT("MUIMComponentDispatch() what=%ld\n", inParams->what);
+
   switch (inParams->what) {
   case kComponentOpenSelect:
-    MUIMLog("MUIMComponentDispatch::kComponentOpenSelect\n");
     result = CallMUIMFunction(inParams, (ProcPtr) MUIMOpenComponent,
                               uppOpenComponentProcInfo);
     break;
 
   case kComponentCloseSelect:
-    MUIMLog("MUIMComponentDispatch::kComponentCloseSelect\n");
     result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
                                          (ProcPtr) MUIMCloseComponent,
                                          uppCloseComponentProcInfo);
     break;
 
   case kComponentCanDoSelect:
-    MUIMLog("MUIMComponentDispatch::kComponentCanDoSelect\n");
     result =
       CallMUIMFunction(inParams, (ProcPtr) MUIMCanDo, uppCanDoProcInfo);
     break;
 
   case kComponentVersionSelect:
-    MUIMLog("MUIMComponentDispatch::kComponentVersionSelect\n");
     result =
       CallMUIMFunction(inParams, (ProcPtr) MUIMGetVersion,
                        uppGetVersionProcInfo);
     break;
 
   case kCMGetScriptLangSupport:
-    MUIMLog("MUIMComponentDispatch::kCMGetScriptLangSupport\n");
     result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
                                          (ProcPtr) MUIMGetScriptLangSupport,
                                          uppGetScriptLangSupportProcInfo);
     break;
 
   case kCMInitiateTextService:
-    MUIMLog("MUIMComponentDispatch::kCMInitiateTextService\n");
     result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
                                          (ProcPtr) MUIMInitiateTextService,
                                          uppInitiateTextServiceProcInfo);
     break;
 
   case kCMTerminateTextService:
-    MUIMLog("MUIMComponentDispatch::kCMTerminateTextService\n");
     result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
                                          (ProcPtr) MUIMTerminateTextService,
                                          uppTerminateTextServiceProcInfo);
     break;
 
   case kCMActivateTextService:
-    MUIMLog("MUIMComponentDispatch::kCMActivateTextService\n");
     result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
                                          (ProcPtr) MUIMActivateTextService,
                                          uppActivateTextServiceProcInfo);
     break;
 
   case kCMDeactivateTextService:
-    MUIMLog("MUIMComponentDispatch::kCMDeactivateTextService\n");
     result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
                                          (ProcPtr) MUIMDeactivateTextService,
                                          uppDeactivateTextServiceProcInfo);
     break;
 
   case kCMTextServiceEvent:
-    MUIMLog("MUIMComponentDispatch::kCMTextServiceEvent\n");
     result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
                                          (ProcPtr) MUIMTextServiceEventRef,
                                          uppTextServiceEventRefProcInfo);
     break;
 
   case kCMGetTextServiceMenu:
-    MUIMLog("MUIMComponentDispatch::kCMGetTextServiceMenu\n");
     result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
                                          (ProcPtr) MUIMGetTextServiceMenu,
                                          uppGetTextServiceMenuProcInfo);
     break;
 
   case kCMFixTextService:
-    MUIMLog("MUIMComponentDispatch::kCMFixTextService\n");
     result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
                                          (ProcPtr) MUIMFixTextService,
                                          uppFixTextServiceProcInfo);
     break;
 
   case kCMHidePaletteWindows:
+    DEBUG_PRINT("MUIMComponentDispatch() kCMHidePaletteWindows\n");
     break;
 
+  /*
+  case kCMGetTextServiceProperty:
+    DEBUG_PRINT("MUIMComponentDispatch() kCMGetTextServiceProperty\n");
+    result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
+                                         (ProcPtr) MUIMGetTextServiceProperty,
+                                         uppGetTextServicePropertyProcInfo);
+    break;
+
+  case kCMSetTextServiceProperty:
+    DEBUG_PRINT("MUIMComponentDispatch() kCMSettTextServiceProperty\n");
+    result = CallMUIMFunctionWithStorage(inSessionHandle, inParams,
+                                         (ProcPtr) MUIMSetTextServiceProperty,
+                                         uppSetTextServicePropertyProcInfo);
+    break;
+
+  case kCMUCTextServiceEvent:
+    DEBUG_PRINT("MUIMComponentDispatch() kCMUCTextServiceEvent¥n");
+    break;
+  */
+
   default:
     result = badComponentSelector;
     break;
@@ -261,6 +274,11 @@ MUIMCanDo(SInt16 inSelector)
   case kCMGetTextServiceMenu:
   case kCMFixTextService:
   case kCMHidePaletteWindows:
+    /*
+  case kCMGetTextServiceProperty: // XXX
+  case kCMSetTextServiceProperty: // XXX
+  case kCMUCTextServiceEvent:     // XXX
+    */
     result = true;
     break;
 
@@ -456,6 +474,26 @@ MUIMFixTextService(Handle inSessionHandle)
   return noErr;
 }
 
+/*
+pascal ComponentResult
+MUIMGetTextServiceProperty(Handle inSessionHandle, OSType inPropSelector,
+                           SInt32 *inProp)
+{
+  *inProp = gProp;
+
+  return noErr;
+}
+
+pascal ComponentResult
+MUIMSetTextServiceProperty(Handle inSessionHandle, OSType inPropSelector,
+                           SInt32 inProp)
+{
+  gProp = inProp;
+
+  return noErr;
+}
+*/
+
 /**
  * Glue code to create a Universal Procedure Pointer for our internal dispatch
  * routines and call them.
