@@ -46,7 +46,7 @@ AddPreeditSegment(MUIMSessionHandle inHandle, int inAttr,
 
 
 void
-UIMCommitString(void *ptr, char *str)
+UIMCommitString(void *ptr, const char *str)
 {
   DEBUG_PRINT("UIMCommitString() len=%d\n", strlen(str));
 
